reference_stable

Macro reference_stable 

macro_rules! reference_stable {
    ($name: tt, $value: expr) => { ... };
}
Create a Reference argument from data with a stable address.

Safety

You must ensure the data has a stable address (heap allocated, static, etc.) and won’t be moved for the lifetime of the reference.