Module node

Module node 

Standard ɴsɪ node types — re-exported from nsi-trait.

The string constants and the NodeType enum live in the nsi-trait crate as the single source of truth. This module re-exports them so user code can write nsi_ffi_wrap::MESH, nsi_ffi_wrap::NURBS, etc.

Enums

NodeType
Node types in the ɴsɪ scene graph.

Constants

ALL
Wildcard node that references all existing nodes at once (.all).
ATTRIBUTES
Container for generic attributes (e.g. visibility). Documentation.
CURVES
Linear, b-spline and Catmull-Rom curves. Documentation.
CYLINDRICAL_CAMERA
A cylindrical camera. Documentation.
ENVIRONMENT
Geometry type to define environment lighting. Documentation.
FACE_SET
Assign attributes to part of a mesh, curves or particles. Documentation.
FISHEYE_CAMERA
A fisheye camera. Documentation.
GLOBAL
Global settings node (.global). Documentation.
INSTANCES
Specifies instances of other nodes. Documentation.
MESH
Polygonal mesh or subdivision surface. Documentation.
NURBS
NURBS surface with optional trim curves.
ORTHOGRAPHIC_CAMERA
An orthographic camera. Documentation.
OUTPUT_DRIVER
A target where to output rendered pixels. Documentation.
OUTPUT_LAYER
Describes one render layer to be connected to an outputdriver node. Documentation.
PARTICLES
Collection of particles. Documentation.
PERSPECTIVE_CAMERA
A perspective camera. Documentation.
PLANE
An infinite plane. Documentation.
PROCEDURAL
Geometry to be loaded or generated in delayed fashion. Documentation.
ROOT
The scene’s root (.root). Documentation.
SCREEN
Describes how the view from a camera node will be rasterized into an outputlayer node. Documentation.
SET
Expresses relationships of groups of nodes. Documentation.
SHADER
OSL shader or layer in a shader group. Documentation.
SPHERICAL_CAMERA
A spherical camera. Documentation.
TRANSFORM
Transformation to place objects in the scene. Documentation.
VOLUME
A volume loaded from an OpenVDB file. Documentation.